Official Invoiced Client Library for Python
===========================================

A Python library for Invoiced's API.


Setup
-----

You can install this package by using the pip tool and installing:

    $ pip install invoiced
    
Or:

    $ easy_install invoiced
    

Setting up a Invoiced Account
-----------------------------

Sign up for Invoiced at https://invoiced.com/signup.

Using the Invoiced API
----------------------

Documentation for the python library can be found here:

- https://invoiced.com/docs/api
